==> spip_4.2.9+dfsg.orig.tar.xz: ecrire/lang/public_da.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/public?lang_cible=da
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'accueil_site' => 'Hjemmeside', # MODIF
	'articles' => 'Artikler',
	'articles_auteur' => 'Denne forfatters artikler',
	'articles_populaires' => 'De mest læste artikler',
	'articles_rubrique' => 'Dette områdes artikler',
	'aucun_article' => 'Der er ingen artikel på denne adresse',
	'aucun_auteur' => 'Der er ingen forfatter på denne adresse',
	'aucun_site' => 'Der er intet websted på denne adresse',
	'aucune_breve' => 'Der er ingen nyhed på denne adresse',
	'aucune_rubrique' => 'Der er ikke noget afsnit på denne adresse',
	'autres_breves' => 'Andre nyheder',
	'autres_groupes_mots_clefs' => 'Andre grupper af nøgleord',
	'autres_sites' => 'Andre websteder',

	// B
	'bonjour' => 'Hej',

	// C
	'commenter_site' => 'Kommentar til dette websted',

	// D
	'date' => 'Dato',
	'dernier_ajout' => 'Seneste tilføjelse',
	'dernieres_breves' => 'Seneste nyhed',
	'derniers_articles' => 'Seneste artikler',
	'derniers_commentaires' => 'Seneste kommentarer',
	'derniers_messages_forum' => 'Seneste indlæg offentliggjort i forummer',

	// E
	'edition_mode_texte' => 'Tekstudgave',
	'en_reponse' => 'Svaradresse:',
	'en_resume' => 'Opsummering',
	'envoyer_message' => 'Lav indlæg',
	'espace_prive' => 'Privat område',

	// H
	'hierarchie_site' => 'Webstedets struktur',

	// J
	'jours' => 'dage',

	// M
	'meme_auteur' => 'Af samme forfatter',
	'meme_rubrique' => 'I samme afsnit',
	'memes_auteurs' => 'Af samme forfattere',
	'message' => 'Indlæg',
	'messages_forum' => 'Forumindlæg', # MODIF
	'messages_recents' => 'Seneste forumindlæg',
	'mots_clefs' => 'Nøgleord',
	'mots_clefs_meme_groupe' => 'Nøgleord i samme gruppe',

	// N
	'navigation' => 'Navigering',
	'nom' => 'Navn',
	'nouveautes' => 'Hvad nyt',
	'nouveautes_web' => 'Hvad nyt på Internettet',
	'nouveaux_articles' => 'Nye artikler',
	'nouvelles_breves' => 'Nyheder',

	// P
	'page_precedente' => 'foregående side',
	'page_suivante' => 'næste side',
	'par_auteur' => 'af',
	'participer_site' => 'Du kan deltage aktivt på dette websted og skrive dine egne artikler ved at tilmelde dig nedenfor. Du vil da straks modtage en email med en adgangskode til webstedets private område.',
	'plan_site' => 'Indholdsoversigt',
	'popularite' => 'Popularitet',
	'poster_message' => 'Indlæg',

	// R
	'repondre_article' => 'Lav et svar til denne artikel',
	'repondre_breve' => 'Lav et svar på denne nyhed',
	'resultats_recherche' => 'Søgeresultater',
	'retour_debut_forums' => 'Tilbage til starten på forummet',
	'rubrique' => 'Afsnit',
	'rubriques' => 'Afsnit',

	// S
	'signatures_petition' => 'Underskrifter',
	'site_realise_avec_spip' => 'Websted lavet med SPIP',
	'sites_web' => 'Websteder',
	'sous_rubriques' => 'Underafsnit',
	'suite' => 'fortsæt',
	'sur_web' => 'På Internettet',
	'syndiquer_rubrique' => 'Syndiker dette afsnit',
	'syndiquer_site' => 'Syndiker hele webstedet',

	// T
	'texte_lettre_information' => 'Her er webstedets nyhedsbrev',
	'texte_lettre_information_2' => 'Dette brev opsummerer artikler og nyheder offentlliggjort siden', # MODIF

	// V
	'ver_imprimer' => 'Printbar version',
	'voir_en_ligne' => 'Se online',
	'voir_squelette' => 'Hent skabelonen til denne side'
);

==> spip_4.4.5+dfsg.orig.tar.xz: ecrire/lang/public_da.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/public?lang_cible=da
// ** ne pas modifier le fichier **

return [

	// A
	'accueil_site' => 'Hjemmeside', # MODIF
	'articles' => 'Artikler',
	'articles_auteur' => 'Denne forfatters artikler',
	'articles_populaires' => 'De mest læste artikler',
	'articles_rubrique' => 'Dette områdes artikler',
	'aucun_article' => 'Der er ingen artikel på denne adresse',
	'aucun_auteur' => 'Der er ingen forfatter på denne adresse',
	'aucun_site' => 'Der er intet websted på denne adresse',
	'aucune_breve' => 'Der er ingen nyhed på denne adresse',
	'aucune_rubrique' => 'Der er ikke noget afsnit på denne adresse',
	'autres_breves' => 'Andre nyheder',
	'autres_groupes_mots_clefs' => 'Andre grupper af nøgleord',
	'autres_sites' => 'Andre websteder',

	// B
	'bonjour' => 'Hej',

	// C
	'commenter_site' => 'Kommentar til dette websted',

	// D
	'date' => 'Dato',
	'dernier_ajout' => 'Seneste tilføjelse',
	'dernieres_breves' => 'Seneste nyhed',
	'derniers_articles' => 'Seneste artikler',
	'derniers_commentaires' => 'Seneste kommentarer',
	'derniers_messages_forum' => 'Seneste indlæg offentliggjort i forummer',

	// E
	'edition_mode_texte' => 'Tekstudgave',
	'en_reponse' => 'Svaradresse:',
	'en_resume' => 'Opsummering',
	'envoyer_message' => 'Lav indlæg',
	'espace_prive' => 'Privat område',

	// H
	'hierarchie_site' => 'Webstedets struktur',

	// J
	'jours' => 'dage',

	// M
	'meme_auteur' => 'Af samme forfatter',
	'meme_rubrique' => 'I samme afsnit',
	'memes_auteurs' => 'Af samme forfattere',
	'message' => 'Indlæg',
	'messages_forum' => 'Forumindlæg', # MODIF
	'messages_recents' => 'Seneste forumindlæg',
	'mots_clefs' => 'Nøgleord',
	'mots_clefs_meme_groupe' => 'Nøgleord i samme gruppe',

	// N
	'navigation' => 'Navigering',
	'nom' => 'Navn',
	'nouveautes' => 'Hvad nyt',
	'nouveautes_web' => 'Hvad nyt på Internettet',
	'nouveaux_articles' => 'Nye artikler',
	'nouvelles_breves' => 'Nyheder',

	// P
	'page_precedente' => 'foregående side',
	'page_suivante' => 'næste side',
	'par_auteur' => 'af',
	'participer_site' => 'Du kan deltage aktivt på dette websted og skrive dine egne artikler ved at tilmelde dig nedenfor. Du vil da straks modtage en email med en adgangskode til webstedets private område.',
	'plan_site' => 'Indholdsoversigt',
	'popularite' => 'Popularitet',
	'poster_message' => 'Indlæg',

	// R
	'repondre_article' => 'Lav et svar til denne artikel',
	'repondre_breve' => 'Lav et svar på denne nyhed',
	'resultats_recherche' => 'Søgeresultater',
	'retour_debut_forums' => 'Tilbage til starten på forummet',
	'rubrique' => 'Afsnit',
	'rubriques' => 'Afsnit',

	// S
	'signatures_petition' => 'Underskrifter',
	'site_realise_avec_spip' => 'Websted lavet med SPIP',
	'sites_web' => 'Websteder',
	'sous_rubriques' => 'Underafsnit',
	'suite' => 'fortsæt',
	'sur_web' => 'På Internettet',
	'syndiquer_rubrique' => 'Syndiker dette afsnit',
	'syndiquer_site' => 'Syndiker hele webstedet',

	// T
	'texte_lettre_information' => 'Her er webstedets nyhedsbrev',
	'texte_lettre_information_2' => 'Dette brev opsummerer artikler og nyheder offentlliggjort siden', # MODIF

	// V
	'ver_imprimer' => 'Printbar version',
	'voir_en_ligne' => 'Se online',
	'voir_squelette' => 'Hent skabelonen til denne side',
];
